@@ -12,20 +12,22 @@ from typing import Union
 
 import requests
 
+from .helpers import _MyIntFlag
+
 __all__ = ['calendar_events', 'Importance', 'Currency']
 
 _BASE_URL = "https://www.mql5.com"
-_OMIT_RESULT_KEYS = ['FullDate']
+_OMIT_RESULT_KEYS = ['FullDate', ]
 
 
-class Importance(enum.IntFlag):
+class Importance(_MyIntFlag):
     HOLIDAY = enum.auto()
     LOW = enum.auto()
     MEDIUM = enum.auto()
     HIGH = enum.auto()
 
 
-class Currency(enum.IntFlag):
+class Currency(_MyIntFlag):
     USD = enum.auto()
     EUR = enum.auto()
     JPY = enum.auto()
@@ -111,7 +113,7 @@ def _get_calendar_events(datetime_from: datetime,
         time = datetime.fromtimestamp(e['ReleaseDate'] / 1000)
         if datetime_from <= time <= datetime_to:
             e['Url'] = _BASE_URL + e['Url']
-            e['ReleaseDate'] = time
+            # e['ReleaseDate'] = time # TOO OPINIONATED JUST DO TIMESTAMP
             e['request'] = data
             formatted_event = {}
             for k, v in e.items():
@@ -148,16 +150,13 @@ def _camel_to_snake(w):
             return cache[w]
         p = _camel_to_snake.pattern
     except AttributeError:
-        p = _camel_to_snake.pattern = re.compile(r'[A-Z][a-z0-9]*')
         cache = _camel_to_snake.cache = {}
+        p = _camel_to_snake.pattern = re.compile(r'[A-Z][a-z0-9]*')
     words = p.findall(w)
     if words:
-        res = '_'.join(map(str.lower, words))
-        cache[w] = res
-        return res
-    else:
-        cache[w] = w
-        return w
+        w = '_'.join(map(str.lower, words))
+    cache[w] = w
+    return w
 
 
 @functools.lru_cache(maxsize=128, typed=True)
@@ -165,16 +164,16 @@ def _make_flag(enum_cls: Union[Type[Importance], Type[Currency]],
                flags: Union[Iterable[str], int, str] = None
                ) -> int:
     if isinstance(flags, int):
-        return int(flags)
+        return flags
     if flags is None:
-        flags = enum_cls.__members__.keys()
+        return enum_cls.all_flags()
     elif isinstance(flags, str):
         flags = flags.replace(',', ' ').split()
     if enum_cls is Currency:
         flags = _split_pairs(flags)
     flags = [enum_cls.__members__.get(f, 0) for f in set(map(str.upper, flags))]
-    flag = functools.reduce(lambda x, y: x | y, flags)
-    return int(flag)
+    flags = functools.reduce(lambda x, y: x | y, flags)
+    return flags
 
 
 def _construct_args(**kw):
