@@ -1,3 +1,5 @@
+import enum
+import functools
 from datetime import datetime
 
 from .types import *
@@ -18,15 +20,6 @@ def as_dict_all(data: Any):
     if T is dict:
         return {k: as_dict_all(v) for k, v in data.items()}
     return data
-    # try:
-    #     return as_dict_all(data._asdict())
-    # except AttributeError:
-    #     T = type(data)
-    #     if T is tuple or T is list:
-    #         return T(as_dict_all(i) for i in data)
-    #     if T is dict:
-    #         return {k: as_dict_all(v) for k, v in data.items()}
-    #     return data
 
 
 def any_symbol(symbol):
@@ -35,10 +28,8 @@ def any_symbol(symbol):
     :param symbol: Any symbol.
     :return: Symbol as string.
     """
-    try:
-        return symbol.name
-    except AttributeError:
-        return symbol
+    name = getattr(symbol, 'name', symbol)
+    return name
 
 
 def reduce_args(kwargs: dict) -> dict:
@@ -106,3 +97,10 @@ def do_trade_action(func, args):
     cleaned['symbol'] = any_symbol(symbol)
     order_request = reduce_combine(request, cleaned)
     return func(order_request)
+
+
+class _MyIntFlag(enum.IntFlag):
+    @classmethod
+    def all_flags(cls):
+        flags = functools.reduce(lambda x, y: x | y, cls)
+        return flags
